@@ -325,7 +325,7 @@ class CloudvectorDAST(object):
 
     def _get_fuzz_details(self, fuzz_type):
         fuzz_values = []
-        fuzz_values.append({"path": fuzz_type,
+        fuzz_values.append({"path": 'os.path.join("fuzzdb","attack")',
                             "fuzz_type": fuzz_type})
         return fuzz_values
 
@@ -833,6 +833,7 @@ class CloudvectorDAST(object):
 
             fuzz_metadata = get_metadata_for_fuzzinput(fuzz_sub_type)
 
+
             if fuzz_metadata:
                 fuzz_metainfo[fuzz_type] = {
                         "description": fuzz_metadata.get("description"),
@@ -844,7 +845,6 @@ class CloudvectorDAST(object):
                         "ease_of_exploitation": fuzz_metadata.get("ease_of_exploitation")
                     }
 
-
             if str(test["outcome"]).lower() == "failed":
                 if not fuzz_metadata:
                     continue
@@ -959,7 +959,7 @@ class CloudvectorDAST(object):
                 continue
             if v["apis_failed"] > 0:
                 progress = 0
-                fuzz_data_processed.insert(0, {"progress": progress, "fuzz_type": k.replace("_fuzz", ""),
+                fuzz_data_processed.insert(0, {"progress": progress, "fuzz_type": k,
                                                "total_apis": v["apis_tested"], "host": os.environ.get("CVIAST_TEST_APP_HOST",""),
                                                "success_apis": v["apis_tested"] - v["apis_failed"],
                                                "failed_apis": v["apis_failed"], "app":"",
@@ -969,7 +969,7 @@ class CloudvectorDAST(object):
             else:
                 progress = 1
                 fuzz_data_processed.append(
-                    {"progress": progress, "fuzz_type": k.replace("_fuzz", ""), "total_apis": v["apis_tested"],
+                    {"progress": progress, "fuzz_type": k, "total_apis": v["apis_tested"],
                      "success_apis": v["apis_tested"] - v["apis_failed"], "failed_apis": v["apis_failed"],
                      "total_tests": v["total_tests"], "success_tests": v["success_tests"], "app":"",
                      "failed_tests": v["failed_tests"], "host": os.environ.get("CVIAST_TEST_APP_HOST",""),
@@ -997,13 +997,14 @@ class CloudvectorDAST(object):
         for severity, types in fuzz_types.items():
             for k, v in types.items():
                 vulns_stats[severity] = len(v.get("executions",[]))
-        with open(output_report, "w+") as file_:
+
+        with open(output_report, "wb+") as file_:
             file_.write(template.render(api_data=api_data, fuzz_data=fuzz_data_processed, total_api_calls=total_api_calls,
                                         total_vulnerabilities=vulnerabilities_found, spaarc_findings=spaarc_findings,
                                         test_time=datetime.datetime.fromtimestamp(time.time()).isoformat(), total_apis_scanned=total_apis,
                                         fuzz_types=fuzz_types, vulns_stats=vulns_stats, fuzz_metadata=fuzz_metainfo,
                                         detailed_report=os.path.join(os.getcwd(),"CVIAST-detailed_report.html"),
-                                        test_lapse_time=str(round(int(report["report"]["summary"]["duration"])/60))+" min(s)"))
+                                        test_lapse_time=str(round(int(report["report"]["summary"]["duration"])/60))+" min(s)").encode("utf-8","ignore"))
         print("CVIAST report saved in " + os.path.join(os.getcwd(),output_report))
 
 def printProgressBar (iteration, total, prefix = '', suffix = '', decimals = 1, length = 100, fill = '█', printEnd = "\r"):
